@@ -25,6 +25,9 @@ class ExternalBackendConf(SharedBackendConfUtils):
     # Getters
     #
 
+    def h2oCluster(self):
+        return self._get_option(self._jconf.h2oCluster())
+
     def h2oClusterHost(self):
         return self._get_option(self._jconf.h2oClusterHost())
 
@@ -124,8 +127,8 @@ class ExternalBackendConf(SharedBackendConfUtils):
     def externalK8sServiceTimeout(self):
         return self._jconf.externalK8sServiceTimeout()
 
-    def h2oCluster(self):
-        return self._get_option(self._jconf.h2oCluster())
+    def mapperXmx(self):
+        return self._jconf.mapperXmx()
 
 
     #
@@ -140,36 +143,36 @@ class ExternalBackendConf(SharedBackendConfUtils):
         self._jconf.useManualClusterStart()
         return self
 
-    def setH2OCluster(self, *args):
-        self._jconf.setH2OCluster(*args)
+    def setH2OCluster(self, value):
+        self._jconf.setH2OCluster(value)
         return self
 
-    def setClusterSize(self, arg0):
-        self._jconf.setClusterSize(arg0)
+    def setClusterSize(self, value):
+        self._jconf.setClusterSize(value)
         return self
 
-    def setClusterStartTimeout(self, arg0):
-        self._jconf.setClusterStartTimeout(arg0)
+    def setClusterStartTimeout(self, value):
+        self._jconf.setClusterStartTimeout(value)
         return self
 
-    def setClusterInfoFile(self, arg0):
-        self._jconf.setClusterInfoFile(arg0)
+    def setClusterInfoFile(self, value):
+        self._jconf.setClusterInfoFile(value)
         return self
 
-    def setExternalMemory(self, arg0):
-        self._jconf.setExternalMemory(arg0)
+    def setExternalMemory(self, value):
+        self._jconf.setExternalMemory(value)
         return self
 
-    def setHDFSOutputDir(self, arg0):
-        self._jconf.setHDFSOutputDir(arg0)
+    def setHDFSOutputDir(self, value):
+        self._jconf.setHDFSOutputDir(value)
         return self
 
-    def setH2ODriverPath(self, arg0):
-        self._jconf.setH2ODriverPath(arg0)
+    def setH2ODriverPath(self, value):
+        self._jconf.setH2ODriverPath(value)
         return self
 
-    def setYARNQueue(self, arg0):
-        self._jconf.setYARNQueue(arg0)
+    def setYARNQueue(self, value):
+        self._jconf.setYARNQueue(value)
         return self
 
     def setKillOnUnhealthyClusterEnabled(self):
@@ -180,82 +183,86 @@ class ExternalBackendConf(SharedBackendConfUtils):
         self._jconf.setKillOnUnhealthyClusterDisabled()
         return self
 
-    def setKerberosPrincipal(self, arg0):
-        self._jconf.setKerberosPrincipal(arg0)
+    def setKerberosPrincipal(self, value):
+        self._jconf.setKerberosPrincipal(value)
         return self
 
-    def setKerberosKeytab(self, arg0):
-        self._jconf.setKerberosKeytab(arg0)
+    def setKerberosKeytab(self, value):
+        self._jconf.setKerberosKeytab(value)
         return self
 
-    def setRunAsUser(self, arg0):
-        self._jconf.setRunAsUser(arg0)
+    def setRunAsUser(self, value):
+        self._jconf.setRunAsUser(value)
         return self
 
-    def setExternalH2ODriverIf(self, arg0):
-        self._jconf.setExternalH2ODriverIf(arg0)
+    def setExternalH2ODriverIf(self, value):
+        self._jconf.setExternalH2ODriverIf(value)
         return self
 
-    def setExternalH2ODriverPort(self, arg0):
-        self._jconf.setExternalH2ODriverPort(arg0)
+    def setExternalH2ODriverPort(self, value):
+        self._jconf.setExternalH2ODriverPort(value)
         return self
 
-    def setExternalH2ODriverPortRange(self, arg0):
-        self._jconf.setExternalH2ODriverPortRange(arg0)
+    def setExternalH2ODriverPortRange(self, value):
+        self._jconf.setExternalH2ODriverPortRange(value)
         return self
 
-    def setExternalExtraMemoryPercent(self, arg0):
-        self._jconf.setExternalExtraMemoryPercent(arg0)
+    def setExternalExtraMemoryPercent(self, value):
+        self._jconf.setExternalExtraMemoryPercent(value)
         return self
 
-    def setExternalBackendStopTimeout(self, arg0):
-        self._jconf.setExternalBackendStopTimeout(arg0)
+    def setExternalBackendStopTimeout(self, value):
+        self._jconf.setExternalBackendStopTimeout(value)
         return self
 
-    def setExternalHadoopExecutable(self, arg0):
-        self._jconf.setExternalHadoopExecutable(arg0)
+    def setExternalHadoopExecutable(self, value):
+        self._jconf.setExternalHadoopExecutable(value)
         return self
 
-    def setExternalExtraJars(self, *args):
-        self._jconf.setExternalExtraJars(*args)
+    def setExternalExtraJars(self, value):
+        self._jconf.setExternalExtraJars(value)
         return self
 
-    def setExternalCommunicationCompression(self, arg0):
-        self._jconf.setExternalCommunicationCompression(arg0)
+    def setExternalCommunicationCompression(self, value):
+        self._jconf.setExternalCommunicationCompression(value)
         return self
 
-    def setExternalAutoStartBackend(self, arg0):
-        self._jconf.setExternalAutoStartBackend(arg0)
+    def setExternalAutoStartBackend(self, value):
+        self._jconf.setExternalAutoStartBackend(value)
         return self
 
-    def setExternalK8sH2OServiceName(self, arg0):
-        self._jconf.setExternalK8sH2OServiceName(arg0)
+    def setExternalK8sH2OServiceName(self, value):
+        self._jconf.setExternalK8sH2OServiceName(value)
         return self
 
-    def setExternalK8sH2OStatefulsetName(self, arg0):
-        self._jconf.setExternalK8sH2OStatefulsetName(arg0)
+    def setExternalK8sH2OStatefulsetName(self, value):
+        self._jconf.setExternalK8sH2OStatefulsetName(value)
         return self
 
-    def setExternalK8sH2OLabel(self, arg0):
-        self._jconf.setExternalK8sH2OLabel(arg0)
+    def setExternalK8sH2OLabel(self, value):
+        self._jconf.setExternalK8sH2OLabel(value)
         return self
 
-    def setExternalK8sH2OApiPort(self, arg0):
-        self._jconf.setExternalK8sH2OApiPort(arg0)
+    def setExternalK8sH2OApiPort(self, value):
+        self._jconf.setExternalK8sH2OApiPort(value)
         return self
 
-    def setExternalK8sNamespace(self, arg0):
-        self._jconf.setExternalK8sNamespace(arg0)
+    def setExternalK8sNamespace(self, value):
+        self._jconf.setExternalK8sNamespace(value)
         return self
 
-    def setExternalK8sDockerImage(self, arg0):
-        self._jconf.setExternalK8sDockerImage(arg0)
+    def setExternalK8sDockerImage(self, value):
+        self._jconf.setExternalK8sDockerImage(value)
         return self
 
-    def setExternalK8sDomain(self, arg0):
-        self._jconf.setExternalK8sDomain(arg0)
+    def setExternalK8sDomain(self, value):
+        self._jconf.setExternalK8sDomain(value)
         return self
 
-    def setExternalK8sServiceTimeout(self, arg0):
-        self._jconf.setExternalK8sServiceTimeout(arg0)
+    def setExternalK8sServiceTimeout(self, value):
+        self._jconf.setExternalK8sServiceTimeout(value)
+        return self
+
+    def setMapperXmx(self, value):
+        self._jconf.setMapperXmx(value)
         return self
