@@ -25,21 +25,15 @@ class SharedBackendConf(SharedBackendConfUtils):
     # Getters
     #
 
-    def cloudName(self):
-        return self._get_option(self._jconf.cloudName())
-
     def backendClusterMode(self):
         return self._jconf.backendClusterMode()
 
+    def cloudName(self):
+        return self._get_option(self._jconf.cloudName())
+
     def isH2OReplEnabled(self):
         return self._jconf.isH2OReplEnabled()
 
-    def isProgressBarEnabled(self):
-        return self._jconf.isProgressBarEnabled()
-
-    def isModelPrintAfterTrainingEnabled(self):
-        return self._jconf.isModelPrintAfterTrainingEnabled()
-
     def scalaIntDefaultNum(self):
         return self._jconf.scalaIntDefaultNum()
 
@@ -61,24 +55,15 @@ class SharedBackendConf(SharedBackendConfUtils):
     def jksAlias(self):
         return self._get_option(self._jconf.jksAlias())
 
-    def sslCACert(self):
-        return self._get_option(self._jconf.sslCACert())
-
     def hashLogin(self):
         return self._jconf.hashLogin()
 
     def ldapLogin(self):
         return self._jconf.ldapLogin()
 
-    def proxyLoginOnly(self):
-        return self._jconf.proxyLoginOnly()
-
     def kerberosLogin(self):
         return self._jconf.kerberosLogin()
 
-    def pamLogin(self):
-        return self._jconf.pamLogin()
-
     def loginConf(self):
         return self._get_option(self._jconf.loginConf())
 
@@ -94,9 +79,15 @@ class SharedBackendConf(SharedBackendConfUtils):
     def autoFlowSsl(self):
         return self._jconf.autoFlowSsl()
 
+    def h2oNodeLogLevel(self):
+        return self._jconf.h2oNodeLogLevel()
+
     def logLevel(self):
         return self._jconf.logLevel()
 
+    def h2oNodeLogDir(self):
+        return self._get_option(self._jconf.h2oNodeLogDir())
+
     def logDir(self):
         return self._get_option(self._jconf.logDir())
 
@@ -124,24 +115,24 @@ class SharedBackendConf(SharedBackendConfUtils):
     def internalPortOffset(self):
         return self._jconf.internalPortOffset()
 
+    def nodeBasePort(self):
+        return self._jconf.nodeBasePort()
+
     def basePort(self):
         return self._jconf.basePort()
 
     def mojoDestroyTimeout(self):
         return self._jconf.mojoDestroyTimeout()
 
+    def nodeExtraProperties(self):
+        return self._get_option(self._jconf.nodeExtraProperties())
+
     def extraProperties(self):
         return self._get_option(self._jconf.extraProperties())
 
     def flowExtraHttpHeaders(self):
         return self._get_option(self._jconf.flowExtraHttpHeaders())
 
-    def flowProxyRequestMaxSize(self):
-        return self._jconf.flowProxyRequestMaxSize()
-
-    def flowProxyResponseMaxSize(self):
-        return self._jconf.flowProxyResponseMaxSize()
-
     def isInternalSecureConnectionsEnabled(self):
         return self._jconf.isInternalSecureConnectionsEnabled()
 
@@ -154,6 +145,21 @@ class SharedBackendConf(SharedBackendConfUtils):
     def clientIp(self):
         return self._get_option(self._jconf.clientIp())
 
+    def clientIcedDir(self):
+        return self._get_option(self._jconf.clientIcedDir())
+
+    def icedDir(self):
+        return self._get_option(self._jconf.icedDir())
+
+    def h2oClientLogLevel(self):
+        return self._jconf.h2oClientLogLevel()
+
+    def h2oClientLogDir(self):
+        return self._get_option(self._jconf.h2oClientLogDir())
+
+    def clientBasePort(self):
+        return self._jconf.clientBasePort()
+
     def clientWebPort(self):
         return self._jconf.clientWebPort()
 
@@ -166,6 +172,9 @@ class SharedBackendConf(SharedBackendConfUtils):
     def clientFlowBaseurlOverride(self):
         return self._get_option(self._jconf.clientFlowBaseurlOverride())
 
+    def clientExtraProperties(self):
+        return self._get_option(self._jconf.clientExtraProperties())
+
     def runsInExternalClusterMode(self):
         return self._jconf.runsInExternalClusterMode()
 
@@ -178,12 +187,6 @@ class SharedBackendConf(SharedBackendConfUtils):
     def verifySslCertificates(self):
         return self._jconf.verifySslCertificates()
 
-    def isSslHostnameVerificationInInternalRestConnectionsEnabled(self):
-        return self._jconf.isSslHostnameVerificationInInternalRestConnectionsEnabled()
-
-    def isSslCertificateVerificationInInternalRestConnectionsEnabled(self):
-        return self._jconf.isSslCertificateVerificationInInternalRestConnectionsEnabled()
-
     def isKerberizedHiveEnabled(self):
         return self._jconf.isKerberizedHiveEnabled()
 
@@ -199,9 +202,6 @@ class SharedBackendConf(SharedBackendConfUtils):
     def hiveToken(self):
         return self._get_option(self._jconf.hiveToken())
 
-    def icedDir(self):
-        return self._get_option(self._jconf.icedDir())
-
     def restApiTimeout(self):
         return self._jconf.restApiTimeout()
 
@@ -221,12 +221,12 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setExternalClusterMode()
         return self
 
-    def setCloudName(self, arg0):
-        self._jconf.setCloudName(arg0)
+    def setCloudName(self, value):
+        self._jconf.setCloudName(value)
         return self
 
-    def setNthreads(self, arg0):
-        self._jconf.setNthreads(arg0)
+    def setNthreads(self, value):
+        self._jconf.setNthreads(value)
         return self
 
     def setReplEnabled(self):
@@ -237,24 +237,8 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setReplDisabled()
         return self
 
-    def setProgressBarEnabled(self):
-        self._jconf.setProgressBarEnabled()
-        return self
-
-    def setProgressBarDisabled(self):
-        self._jconf.setProgressBarDisabled()
-        return self
-
-    def setModelPrintAfterTrainingEnabled(self):
-        self._jconf.setModelPrintAfterTrainingEnabled()
-        return self
-
-    def setModelPrintAfterTrainingDisabled(self):
-        self._jconf.setModelPrintAfterTrainingDisabled()
-        return self
-
-    def setDefaultNumReplSessions(self, arg0):
-        self._jconf.setDefaultNumReplSessions(arg0)
+    def setDefaultNumReplSessions(self, value):
+        self._jconf.setDefaultNumReplSessions(value)
         return self
 
     def setClusterTopologyListenerEnabled(self):
@@ -281,20 +265,16 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setFailOnUnsupportedSparkParamDisabled()
         return self
 
-    def setJks(self, arg0):
-        self._jconf.setJks(arg0)
+    def setJks(self, value):
+        self._jconf.setJks(value)
         return self
 
-    def setJksPass(self, arg0):
-        self._jconf.setJksPass(arg0)
+    def setJksPass(self, value):
+        self._jconf.setJksPass(value)
         return self
 
-    def setJksAlias(self, arg0):
-        self._jconf.setJksAlias(arg0)
-        return self
-
-    def setSslCACert(self, arg0):
-        self._jconf.setSslCACert(arg0)
+    def setJksAlias(self, value):
+        self._jconf.setJksAlias(value)
         return self
 
     def setHashLoginEnabled(self):
@@ -313,14 +293,6 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setLdapLoginDisabled()
         return self
 
-    def setProxyLoginOnlyEnabled(self):
-        self._jconf.setProxyLoginOnlyEnabled()
-        return self
-
-    def setProxyLoginOnlyDisabled(self):
-        self._jconf.setProxyLoginOnlyDisabled()
-        return self
-
     def setKerberosLoginEnabled(self):
         self._jconf.setKerberosLoginEnabled()
         return self
@@ -329,28 +301,20 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setKerberosLoginDisabled()
         return self
 
-    def setPamLoginEnabled(self):
-        self._jconf.setPamLoginEnabled()
+    def setLoginConf(self, value):
+        self._jconf.setLoginConf(value)
         return self
 
-    def setPamLoginDisabled(self):
-        self._jconf.setPamLoginDisabled()
+    def setUserName(self, value):
+        self._jconf.setUserName(value)
         return self
 
-    def setLoginConf(self, arg0):
-        self._jconf.setLoginConf(arg0)
+    def setPassword(self, value):
+        self._jconf.setPassword(value)
         return self
 
-    def setUserName(self, arg0):
-        self._jconf.setUserName(arg0)
-        return self
-
-    def setPassword(self, arg0):
-        self._jconf.setPassword(arg0)
-        return self
-
-    def setSslConf(self, arg0):
-        self._jconf.setSslConf(arg0)
+    def setSslConf(self, value):
+        self._jconf.setSslConf(value)
         return self
 
     def setAutoFlowSslEnabled(self):
@@ -361,32 +325,40 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setAutoFlowSslDisabled()
         return self
 
-    def setLogLevel(self, arg0):
-        self._jconf.setLogLevel(arg0)
+    def setH2ONodeLogLevel(self, value):
+        self._jconf.setH2ONodeLogLevel(value)
         return self
 
-    def setLogDir(self, arg0):
-        self._jconf.setLogDir(arg0)
+    def setLogLevel(self, value):
+        self._jconf.setLogLevel(value)
         return self
 
-    def setBackendHeartbeatInterval(self, arg0):
-        self._jconf.setBackendHeartbeatInterval(arg0)
+    def setH2ONodeLogDir(self, value):
+        self._jconf.setH2ONodeLogDir(value)
         return self
 
-    def setCloudTimeout(self, arg0):
-        self._jconf.setCloudTimeout(arg0)
+    def setLogDir(self, value):
+        self._jconf.setLogDir(value)
         return self
 
-    def setNodeNetworkMask(self, arg0):
-        self._jconf.setNodeNetworkMask(arg0)
+    def setBackendHeartbeatInterval(self, value):
+        self._jconf.setBackendHeartbeatInterval(value)
         return self
 
-    def setStacktraceCollectorInterval(self, arg0):
-        self._jconf.setStacktraceCollectorInterval(arg0)
+    def setCloudTimeout(self, value):
+        self._jconf.setCloudTimeout(value)
         return self
 
-    def setContextPath(self, arg0):
-        self._jconf.setContextPath(arg0)
+    def setNodeNetworkMask(self, value):
+        self._jconf.setNodeNetworkMask(value)
+        return self
+
+    def setStacktraceCollectorInterval(self, value):
+        self._jconf.setStacktraceCollectorInterval(value)
+        return self
+
+    def setContextPath(self, value):
+        self._jconf.setContextPath(value)
         return self
 
     def setFlowScalaCellAsyncEnabled(self):
@@ -397,36 +369,36 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setFlowScalaCellAsyncDisabled()
         return self
 
-    def setMaxParallelScalaCellJobs(self, arg0):
-        self._jconf.setMaxParallelScalaCellJobs(arg0)
+    def setMaxParallelScalaCellJobs(self, value):
+        self._jconf.setMaxParallelScalaCellJobs(value)
         return self
 
-    def setInternalPortOffset(self, arg0):
-        self._jconf.setInternalPortOffset(arg0)
+    def setInternalPortOffset(self, value):
+        self._jconf.setInternalPortOffset(value)
         return self
 
-    def setBasePort(self, arg0):
-        self._jconf.setBasePort(arg0)
+    def setNodeBasePort(self, value):
+        self._jconf.setNodeBasePort(value)
         return self
 
-    def setMojoDestroyTimeout(self, arg0):
-        self._jconf.setMojoDestroyTimeout(arg0)
+    def setBasePort(self, value):
+        self._jconf.setBasePort(value)
         return self
 
-    def setExtraProperties(self, arg0):
-        self._jconf.setExtraProperties(arg0)
+    def setMojoDestroyTimeout(self, value):
+        self._jconf.setMojoDestroyTimeout(value)
         return self
 
-    def setFlowExtraHttpHeaders(self, *args):
-        self._jconf.setFlowExtraHttpHeaders(*args)
+    def setNodeExtraProperties(self, value):
+        self._jconf.setNodeExtraProperties(value)
         return self
 
-    def setFlowProxyRequestMaxSize(self, arg0):
-        self._jconf.setFlowProxyRequestMaxSize(arg0)
+    def setExtraProperties(self, value):
+        self._jconf.setExtraProperties(value)
         return self
 
-    def setFlowProxyResponseMaxSize(self, arg0):
-        self._jconf.setFlowProxyResponseMaxSize(arg0)
+    def setFlowExtraHttpHeaders(self, value):
+        self._jconf.setFlowExtraHttpHeaders(value)
         return self
 
     def setInternalSecureConnectionsEnabled(self):
@@ -445,16 +417,36 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setInsecureXGBoostDenied()
         return self
 
-    def setFlowDir(self, arg0):
-        self._jconf.setFlowDir(arg0)
+    def setFlowDir(self, value):
+        self._jconf.setFlowDir(value)
         return self
 
-    def setClientIp(self, arg0):
-        self._jconf.setClientIp(arg0)
+    def setClientIp(self, value):
+        self._jconf.setClientIp(value)
         return self
 
-    def setClientWebPort(self, arg0):
-        self._jconf.setClientWebPort(arg0)
+    def setClientIcedDir(self, value):
+        self._jconf.setClientIcedDir(value)
+        return self
+
+    def setIcedDir(self, value):
+        self._jconf.setIcedDir(value)
+        return self
+
+    def setH2OClientLogLevel(self, value):
+        self._jconf.setH2OClientLogLevel(value)
+        return self
+
+    def setH2OClientLogDir(self, value):
+        self._jconf.setH2OClientLogDir(value)
+        return self
+
+    def setClientBasePort(self, value):
+        self._jconf.setClientBasePort(value)
+        return self
+
+    def setClientWebPort(self, value):
+        self._jconf.setClientWebPort(value)
         return self
 
     def setClientVerboseEnabled(self):
@@ -465,36 +457,24 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setClientVerboseDisabled()
         return self
 
-    def setClientNetworkMask(self, arg0):
-        self._jconf.setClientNetworkMask(arg0)
+    def setClientNetworkMask(self, value):
+        self._jconf.setClientNetworkMask(value)
         return self
 
-    def setClientFlowBaseurlOverride(self, arg0):
-        self._jconf.setClientFlowBaseurlOverride(arg0)
+    def setClientFlowBaseurlOverride(self, value):
+        self._jconf.setClientFlowBaseurlOverride(value)
         return self
 
-    def setClientCheckRetryTimeout(self, arg0):
-        self._jconf.setClientCheckRetryTimeout(arg0)
+    def setClientCheckRetryTimeout(self, value):
+        self._jconf.setClientCheckRetryTimeout(value)
         return self
 
-    def setVerifySslCertificates(self, arg0):
-        self._jconf.setVerifySslCertificates(arg0)
+    def setClientExtraProperties(self, value):
+        self._jconf.setClientExtraProperties(value)
         return self
 
-    def setSslHostnameVerificationInInternalRestConnectionsEnabled(self):
-        self._jconf.setSslHostnameVerificationInInternalRestConnectionsEnabled()
-        return self
-
-    def setSslHostnameVerificationInInternalRestConnectionsDisabled(self):
-        self._jconf.setSslHostnameVerificationInInternalRestConnectionsDisabled()
-        return self
-
-    def setSslCertificateVerificationInInternalRestConnectionsEnabled(self):
-        self._jconf.setSslCertificateVerificationInInternalRestConnectionsEnabled()
-        return self
-
-    def setSslCertificateVerificationInInternalRestConnectionsDisabled(self):
-        self._jconf.setSslCertificateVerificationInInternalRestConnectionsDisabled()
+    def setVerifySslCertificates(self, value):
+        self._jconf.setVerifySslCertificates(value)
         return self
 
     def setKerberizedHiveEnabled(self):
@@ -505,26 +485,22 @@ class SharedBackendConf(SharedBackendConfUtils):
         self._jconf.setKerberizedHiveDisabled()
         return self
 
-    def setHiveHost(self, arg0):
-        self._jconf.setHiveHost(arg0)
+    def setHiveHost(self, value):
+        self._jconf.setHiveHost(value)
         return self
 
-    def setHivePrincipal(self, arg0):
-        self._jconf.setHivePrincipal(arg0)
+    def setHivePrincipal(self, value):
+        self._jconf.setHivePrincipal(value)
         return self
 
-    def setHiveJdbcUrlPattern(self, arg0):
-        self._jconf.setHiveJdbcUrlPattern(arg0)
+    def setHiveJdbcUrlPattern(self, value):
+        self._jconf.setHiveJdbcUrlPattern(value)
         return self
 
-    def setHiveToken(self, arg0):
-        self._jconf.setHiveToken(arg0)
+    def setHiveToken(self, value):
+        self._jconf.setHiveToken(value)
         return self
 
-    def setIcedDir(self, arg0):
-        self._jconf.setIcedDir(arg0)
-        return self
-
-    def setRestApiTimeout(self, arg0):
-        self._jconf.setRestApiTimeout(arg0)
+    def setRestApiTimeout(self, value):
+        self._jconf.setRestApiTimeout(value)
         return self
