@@ -21,10 +21,11 @@ from ai.h2o.sparkling import Initializer
 from ai.h2o.sparkling.ml.Utils import Utils
 from ai.h2o.sparkling.ml.algos.H2OAlgorithm import H2OAlgorithm
 from ai.h2o.sparkling.ml.params.H2OGridSearchParams import H2OGridSearchParams
+from ai.h2o.sparkling.ml.params.H2OCommonParams import H2OCommonParams
 from ai.h2o.sparkling.ml.algos.H2OGridSearchExtras import H2OGridSearchExtras
 
 
-class H2OGridSearch(H2OGridSearchParams, H2OAlgorithm, H2OGridSearchExtras):
+class H2OGridSearch(H2OGridSearchParams, H2OCommonParams, H2OAlgorithm, H2OGridSearchExtras):
 
     @keyword_only
     def __init__(self,
@@ -44,7 +45,6 @@ class H2OGridSearch(H2OGridSearchParams, H2OAlgorithm, H2OGridSearchExtras):
         self._java_obj = self._new_java_obj("ai.h2o.sparkling.ml.algos.H2OGridSearch", self.uid)
         self._setDefaultValuesFromJava()
         kwargs = Utils.getInputKwargs(self)
-        kwargs = self._updateInitKwargs(kwargs)
 
         if 'interactionPairs' in kwargs:
             warn("Interaction pairs are not supported!")
