@@ -501,12 +501,6 @@ class H2ODeepLearningParams(HasInitialBiases, HasInitialWeights, HasIgnoredCols,
         """Automatically export generated models to this directory.""",
         H2OTypeConverters.toNullableString())
 
-    aucType = Param(
-        Params._dummy(),
-        "aucType",
-        """Set default multinomial AUC type.""",
-        H2OTypeConverters.toEnumString("hex.MultinomialAucType"))
-
     ##
     # Getters
     ##
@@ -747,9 +741,6 @@ class H2ODeepLearningParams(HasInitialBiases, HasInitialWeights, HasIgnoredCols,
     def getExportCheckpointsDir(self):
         return self.getOrDefault(self.exportCheckpointsDir)
 
-    def getAucType(self):
-        return self.getOrDefault(self.aucType)
-
     ##
     # Setters
     ##
@@ -989,6 +980,3 @@ class H2ODeepLearningParams(HasInitialBiases, HasInitialWeights, HasIgnoredCols,
 
     def setExportCheckpointsDir(self, value):
         return self._set(exportCheckpointsDir=value)
-
-    def setAucType(self, value):
-        return self._set(aucType=value)
